function savetodat(filename, header, varargin)
    % SAVETODAT Saves input table or list of vectors to a dat file
    % Note:
    %   This inputs need to have the same dimensions to be concatenated into a single output array.
    %
    % -----
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % Apache 2.0 License
    % https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox

    % ----------------------------------------------------------------------------------------------

    import af_tools.utils.vecttocol
    import af_tools.utils.appendextension

    filename = appendextension(filename, '.dat');

    datatable = [];
    for i = 1:length(varargin)
        col = vecttocol(varargin{i});
        datatable = [datatable, col];
    end

    data = num2str(datatable, '%0.7f  ');
    contents = char(header, data);
    dlmwrite(filename, contents, 'delimiter', '');

end
